/*************************************************************************/

/*                                                                       */

/* Project     : ECE292B Lab 3                                           */

/*                                                                       */

/* File        : led.c                                                   */

/*                                                                       */

/* Abstract    : LED interface                                           */

/*                                                                       */

/* Author      : Robert Morrison                                         */

/*                                                                       */

/* Date        : 6-02-01                                                 */

/*                                                                       */

/* History     : 6-02-01 RRM                                             */

/*               Initial Revision                                        */

/*                                                                       */

/*************************************************************************/



/* Includes */



#include <windows.h>

#include "dlportio.h"

#include "led.h"



/* Types */



/* Defines */



/* The LED's are controlled through this port address (LPT1) */

#define PORT_ADDR     0x378



/* Local data */

unsigned char led_state = 0x00;



/* Controls the LED's */

void led_ctrl(const unsigned char led_mask);



/* Interface definitions */



/*************************************************************************/

/*                                                                       */

/* Name        : led_on                            EXTERNALIZED FUNCTION */

/*                                                                       */

/* Description : Turn on leds                                            */

/*                                                                       */

/* Arguments   : leds - LED's to turn on                                 */

/*                                                                       */

/* Returns     : None                                                    */

/*                                                                       */

/* Remarks     : OR the LED masks together and pass them into this       */

/*               function to turn on multiple LED's                      */

/*                                                                       */

/*               The LED's are accessed through the parallel port        */

/*                                                                       */

/*************************************************************************/

void led_on(const unsigned char leds)

{

   led_state |= leds; /* OR in the led's to turn on */

   led_ctrl(led_state);

} /* end - led_on() */





/*************************************************************************/

/*                                                                       */

/* Name        : led_off                           EXTERNALIZED FUNCTION */

/*                                                                       */

/* Description : Turn off leds                                           */

/*                                                                       */

/* Arguments   : leds - LED's to turn off                                */

/*                                                                       */

/* Returns     : None                                                    */

/*                                                                       */

/* Remarks     : OR the LED masks together and pass them into this       */

/*               function to turn off multiple LED's                     */

/*                                                                       */

/*               The LED's are accessed through the parallel port        */

/*                                                                       */

/*************************************************************************/

void led_off(const unsigned char leds)

{

   led_state &= ~leds; /* NAND in the led's to turn off */

   led_ctrl(led_state);

} /* end - led_off() */





/*************************************************************************/

/*                                                                       */

/* Name        : led_ctrl                                                */

/*                                                                       */

/* Description : Controls the leds                                       */

/*                                                                       */

/* Arguments   : state - LED states                                      */

/*                                                                       */

/* Returns     : None                                                    */

/*                                                                       */

/* Remarks     : None                                                    */

/*                                                                       */

/*************************************************************************/

void led_ctrl(const unsigned char state)

{

   DlPortWritePortUchar(PORT_ADDR, state);

} /* end - led_ctrl() */